
library(devtools)
#install.packages("letsR_4.0.tar.gz", repos = NULL, type="source")

# load packages 
library(ape)
library(phytools)
require(PCPS)
require(SYNCSA)
library(maptools)
require(rgdal)
require(raster)
require(picante)
require(geiger)
library(Hmisc)
library(phylotools)
library(adephylo)
library(ggplot2)
library(wesanderson)
library(RColorBrewer)
library(graphics)
library(matlab)
library(gmt)
library(letsR)
library(sf)
#library(phyloextra)
#library(rphast)


# first you will need the shapefiles for each one of the species you will work.
# Shapefiles can be download on the IUCN website

# here is an example with 11 Canidae species from South America

setwd("...")# define where are the shapefiles in your computer

species1 <- st_read("Atelocynus microtis.shp")
species2 <- st_read("Cerdocyon thous.shp")
species3 <- st_read("Chrysocyon brachyurus.shp")
species4 <- st_read("Dusicyon australis.shp")
species5 <- st_read("Pseudalopex culpaeus.shp")
species6 <- st_read("Pseudalopex fulvipes.shp")
species7 <- st_read("Pseudalopex griseus.shp")
species8 <- st_read("Pseudalopex gymnocercus.shp")
species9 <- st_read("Pseudalopex sechurae.shp")
species10 <- st_read("Pseudalopex vetulus.shp")
species11 <- st_read("Speothos venaticus.shp")


# Now we will combine all the shapefiles into only one shape
combined_species <- rbind(species1, 
                          species2, 
                          species3, 
                          species4, 
                          species5, 
                          species6, 
                          species7, 
                          species8, 
                          species9, 
                          species10, 
                          species11)

plot(combined_species)


st_crs(combined_species) <- 4326  # define the projection



# here we save the new shapefile created with all the 11 species
# this step is only for you to have the .shp file in your computer
st_write(combined_species, "combined_SA_canids.shp")


# Now we can import this shapefile
canids<-readOGR("combined_SA_canids.shp")



######################################################################################################################################
# This step now is very important. 

# Here we will dived the planet into gridcells (in our case here, in a resolution of 1 degrees)
# so we need to set the coordinate as the limites of the planet 
# So...from these gridcells, we will obtain a presence/absence matrix with all the species that are within each grid in South America

PAM<- lets.presab(canids, xmn = -180, xmx = 180,
                  ymn = -90, ymx = 90, res = 1, remove.cells=T) # "res" means the resolution and "remove.cells=T" will not consider cells that do not have species 

summary(PAM)

plot(PAM)


# set the color palettes
display.brewer.all() 
plot(PAM, col_rich = colorRampPalette(brewer.pal(7, "YlOrRd")), col_name = "blue") # we will use the pallet YlOrRd with up to 7 categories

# now we define the presence/absence matrix form the PAM object, which has more things in it
presab <- PAM$P
colnames(presab) <- gsub(" ", "_", colnames(presab))

presab[1:5, 1:3] #plot the first 5 lines and 3 columns just to check the format


# Now we save the Presence/Absence matrix (Matriz W)
write.table(presab,"pre_aus_SAM_canids_3X3.txt",sep=";")



################################################################################

###### RUN THE COLOR_PALETTE.R" script 

# here you need to run the script "color_palette.R". This scritp has a function 
# to create a color palette. It has several color because you might want use 
# several species over the planet. You need to run this function in order to
# plot the results at the end

################################################################################


#####################################################################################
##########################                                   ########################
##########################                  CWM              ########################
##########################                                   ########################
#####################################################################################


# We will calculate now the metric called community-weighted mean (CWM) which basically will define a mean trait value for
# a gridcell based on all the species within that grid

# read the pre/abs matrix
comm<-read.table("pre_aus_SAM_canids_3X3.txt",header=T, sep=";")

# Here we get the trait values we want to observe across the globe
# I will give an example with a some traits that I used during my phd (traits.txt)
traits=read.table("traits.txt", h=T)

# now we organizes the data, placing the matrices of community and traits in the same order. 
org<-organize.syncsa(comm=comm[3:13], traits=traits)
str(org)

# get the CWM values using the matrix.t function
matrixt_scale<-matrix.t(org$community,org$traits,scale=FALSE)
str(matrixt_scale)
matrixt_extract_scale<-(matrixt_scale$matrix.T)
str(matrixt_extract_scale)


write.table(matrixt_extract_scale, "values_cwm_3x3.txt", sep=";")


#####################################################################################
##########################                                   ########################
##########################      plot traits over the map     ########################
##########################                                   ########################
#####################################################################################


# You will need a shapefile of the planet borders just to make a better map. 
# I use here as an example the file "continent.shp"
conti <- readShapeSpatial("continent.shp")
plot(conti)
SA<-conti
plot(SA)
projection(SA)<-"+proj=longlat +datum=WGS84"

# read our cwm matrix
cwm_traits=read.table("values_cwm_3x3.txt", h=T,sep=";")



################
#### PLOTS

#Body size
body_size<- cbind(comm[,1:2],cwm_traits[,1])
body_size_plot<-rasterFromXYZ(body_size)
plot(body_size_plot,col=jet.colors(100))
plot(SA, bg="transparent", add=TRUE)
title("Body size")


#Brain size
brain_size<- cbind(comm[,1:2],cwm_traits[,2])
brain_size_plot<-rasterFromXYZ(brain_size)
plot(brain_size_plot,col=jet.colors(100))
plot(SA, bg="transparent", add=TRUE)
title("Brain size")


#Body weight 
Body_weight<- cbind(comm[,1:2],cwm_traits[,3])
Body_weight_plot<-rasterFromXYZ(Body_weight)
plot(Body_weight_plot,col=jet.colors(100))
plot(SA, bg="transparent", add=TRUE)
title("Body weight")


#Bite force
Bite_force<- cbind(comm[,1:2],cwm_traits[,4])
Bite_force_plot<-rasterFromXYZ(Bite_force)
plot(Bite_force_plot,col=jet.colors(100))
plot(SA, bg="transparent", add=TRUE)
title("Bite force")
